@@ -13,8 +13,8 @@
 // Load main frame
 //============================================================================
 define([
-    'text!vp_base/html/mainFrame.html!strip',
-    'css!vp_base/css/mainFrame.css',
+    __VP_TEXT_LOADER__('vp_base/html/mainFrame.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/mainFrame'), // INTEGRATION: unified version of css loader
 
     // load module
     './com/com_Config',
@@ -69,16 +69,27 @@ define([
 
             // window resize event
             $(window).resize(function(evt){
-                let jupyterHeadHeight = $('#' + JUPYTER_HEADER_ID).height();
-                let jupyterBodyHeight = $('#' + JUPYTER_NOTEBOOK_ID).height();
-                
-                let vpWidth = $('#vp_wrapper')[0].getBoundingClientRect().width;
-                let vpHeight = $(window).height() - jupyterHeadHeight;
-
-                // $('#vp_wrapper').css( { height: vpHeight + 'px' });
-                that._resizeNotebook(vpWidth);
+                that._resizeWindow();
             });
 
+            // CHROME: colab header toggle
+            if (vpConfig.extensionType === 'colab') {
+                $('#toggle-header-button').click(function(evt) {
+                    console.log('[vp] click toggle header ')
+                    // change height
+                    let colabHeaderVisible = $('#header').is(':visible');
+                    let colabHeaderHeight = $('#header').height() * colabHeaderVisible;
+                    let colabFooterHeight = $('colab-status-bar').height();
+
+                    let colabHeight = colabHeaderHeight + colabFooterHeight + 2;
+
+                    $('#vp_wrapper').css( { 
+                        height:  'calc(100% - ' + colabHeight + 'px)',
+                        top: colabHeaderHeight + 'px' 
+                    });
+                });
+            }
+
             window.vpEvent = new com_Event(this);
         }
 
@@ -92,25 +103,57 @@ define([
             // get visualpython minimum width
             // resizable setting
             // $('#vp_wrapper').resizable('disable');
-            $('#vp_wrapper').resizable({
-                // alsoResize: '#vp_menuFrame',
-                helper: 'vp-wrapper-resizer',
-                handles: 'w',
-                // resizeHeight: false,
-                minWidth: this.minWidth,
-                // maxWidth: 0,
-                start: function(event, ui) {
-                    
-                },
-                resize: function(event, ui) {
-                    // resize #vp_wrapper with currentWidth and resize jupyter area
-                    var currentWidth = ui.size.width;
-                    that._resizeVp(currentWidth);
-                },
-                stop: function(event, ui) {
-                    $('#vp_wrapper').css({'left': '', 'height': ''});
-                }
-            });  
+            if (vpConfig.extensionType !== 'lab') {
+                $('#vp_wrapper').resizable({
+                    // alsoResize: '#vp_menuFrame',
+                    helper: 'vp-wrapper-resizer',
+                    handles: 'w',
+                    // resizeHeight: false,
+                    minWidth: this.minWidth,
+                    // maxWidth: 0,
+                    start: function(event, ui) {
+                        
+                    },
+                    resize: function(event, ui) {
+                        // resize #vp_wrapper with currentWidth and resize jupyter area
+                        var currentWidth = ui.size.width;
+                        that._resizeVp(currentWidth);
+                    },
+                    stop: function(event, ui) {
+                        $('#vp_wrapper').css({'left': '', 'height': ''});
+                    }
+                });  
+            }
+        }
+
+        _resizeWindow() {
+            // CHROME: resize colab
+            if (vpConfig.extensionType === 'notebook') {
+                let jupyterHeadHeight = $('#' + JUPYTER_HEADER_ID).height();
+                let jupyterBodyHeight = $('#' + JUPYTER_NOTEBOOK_ID).height();
+
+                let vpWidth = $('#vp_wrapper')[0].getBoundingClientRect().width;
+                let vpHeight = $(window).height() - jupyterHeadHeight;
+
+                $('#vp_wrapper').css( { height: vpHeight + 'px' });
+                this._resizeNotebook(vpWidth);
+            } else if (vpConfig.extensionType === 'colab') {
+                let colabHeaderVisible = $('#header').is(':visible');
+                let colabHeaderHeight = $('#header').height() * colabHeaderVisible;
+                let colabFooterHeight = $('colab-status-bar').height();
+
+                let colabHeight = colabHeaderHeight + colabFooterHeight + 2;
+
+                let vpWidth = $('#vp_wrapper')[0].getBoundingClientRect().width;
+
+                $('#vp_wrapper').css( { 
+                    height:  'calc(100% - ' + colabHeight + 'px)',
+                    top: colabHeaderHeight + 'px'
+                });
+                this._resizeNotebook(vpWidth);
+            } else if (vpConfig.extensionType === 'lab') {
+                // LAB: do nothing
+            }
         }
 
         _resizeVp(currentWidth) {
@@ -161,8 +204,14 @@ define([
             let nbWidth = baseWidth - vpWidth;
             let nbContainerWidth = nbWidth - 60;
             // apply resized width
-            $('#' + JUPYTER_NOTEBOOK_ID).css({ 'width': nbWidth + 'px' });
-            $('#notebook-container').css({ 'width': nbContainerWidth + 'px' });
+            // CHROME: resize colab
+            if (vpConfig.extensionType === 'notebook') {
+                $('#' + JUPYTER_NOTEBOOK_ID).css({ 'width': nbWidth + 'px' });
+                $('#notebook-container').css({ 'width': nbContainerWidth + 'px' });
+            } else if (vpConfig.extensionType === 'colab') {
+                $('.notebook-horizontal').css({ 'width': nbWidth + 'px' });
+                // $('#notebook-container').css({ 'width': nbContainerWidth + 'px' });
+            }
         }
 
         _getMenuGroupRootType(menu) {
@@ -175,14 +224,12 @@ define([
         //========================================================================
         // External call function
         //========================================================================
-        /**
-         * Load main frame
-         */
-        loadMainFrame() {
-            // load vp_wrapper into jupyter base
+        renderMainFrame() {
             this.$pageDom = $(vpHtml);
-            $(this.$pageDom).prependTo(document.body);
-
+            this.$pageDom.addClass(vpConfig.extensionType);
+            return this.$pageDom;
+        }
+        afterAttach() {
             // set vp width using metadata
             let metadata = vpConfig.getMetadata();
             let { vp_position, vp_note_display, vp_menu_width, vp_note_width } = metadata;
@@ -193,9 +240,6 @@ define([
             if (!vp_note_display) {
                 this.minWidth = MENU_MIN_WIDTH + MENU_BOARD_SPACING;
             }
-
-            // resize jupyterNotebook area
-            let vpWidth = $('#vp_wrapper')[0].getBoundingClientRect().width;
             
             // load menu & board
             this._menuFrame = new MenuFrame($('#vp_wrapper'), 
@@ -207,11 +251,24 @@ define([
                 { parent: this }
             );
             
-            this._resizeNotebook(vpWidth);
+            // consider height and width
+            this._resizeWindow();
             
             // bind event
             this._bindEvent();
             this._bindResizable();
+        }
+        /**
+         * Load main frame
+         */
+        loadMainFrame() {
+            // load vp_wrapper into jupyter base
+            this.renderMainFrame();
+            
+            // prepend
+            $(this.$pageDom).prependTo(document.body);
+
+            this.afterAttach();
 
             return this.$pageDom;
         }
@@ -221,7 +278,8 @@ define([
             let vpWidth = $('#vp_wrapper')[0].clientWidth;
 
             let metadata = vpConfig.getMetadata();
-            let { vp_position, vp_menu_width, vp_note_width } = metadata;
+            vpLog.display(VP_LOG_TYPE.DEVELOP, 'toggle vp with metadata', metadata);
+            let { vp_position, vp_menu_width, vp_note_width, vp_note_display } = metadata;
             let newMetadata = { vp_section_display: !vpDisplay };
             if (vpDisplay) {
                 // hide
@@ -229,11 +287,15 @@ define([
                 $('#vp_wrapper').hide();
             } else {
                 // show
-                vpWidth = vp_position.width;
-                if (vp_position.width == 0) {
-                    vpWidth = (vp_menu_width + vp_note_width + MENU_BOARD_SPACING) + 'px';
+                if (!vp_position || vp_position.width <= 0) {
+                    vpWidth = (vp_menu_width + vp_note_width + MENU_BOARD_SPACING);
+                    if (!vpWidth) {
+                        vpWidth = com_Config.MENU_MIN_WIDTH + (vp_note_display? com_Config.BOARD_MIN_WIDTH: 0) + com_Config.MENU_BOARD_SPACING;
+                    }
                     newMetadata['vp_position'] = { width: vpWidth };
                     $('#vp_wrapper').css({ width: vpWidth });
+                } else {
+                    vpWidth = vp_position.width;
                 }
                 $('#vp_wrapper').show();
             }
@@ -249,8 +311,10 @@ define([
         openVp() {
             $('#vp_wrapper').show();
 
-            let vpWidth = $('#vp_wrapper')[0].clientWidth;
-            this._resizeNotebook(vpWidth);
+            if ($('#vp_wrapper').length > 0) {
+                let vpWidth = $('#vp_wrapper')[0].clientWidth;
+                this._resizeNotebook(vpWidth);
+            }
 
             vpLog.display(VP_LOG_TYPE.DEVELOP, 'vp opened');
         }
@@ -270,7 +334,29 @@ define([
                 this.boardFrame.hide();
                 newVpWidth = menuWidth + MENU_BOARD_SPACING;
                 $('#vp_wrapper').width(newVpWidth);
-                $('#vp_wrapper').resizable({ minWidth: MENU_MIN_WIDTH + MENU_BOARD_SPACING });
+                if (vpConfig.extensionType === 'lab') {
+                    // LAB: set parent width and position, min-width
+                    let target = $('#vp_wrapper').parent();
+                    let prevWidth = target[0].getBoundingClientRect().width;
+                    let prevLeft = $(target).position().left;
+                    let widthDiff = newVpWidth - vpWidth;
+                    $(target).css({
+                        width: prevWidth + widthDiff,
+                        left: prevLeft - widthDiff
+                    });
+                    $('#vp_wrapper').attr('style', `min-width: ${MENU_MIN_WIDTH + MENU_BOARD_SPACING}px !important`);
+                    if (vpLab.shell.rightCollapsed == false) {
+                        vpLab.shell.collapseRight();
+                        vpLab.shell.expandRight();
+                    }
+                    let relativeSizes = vpLab.shell._hsplitPanel.layout.relativeSizes();
+                    let absoluteSizes = vpLab.shell._hsplitPanel.layout.absoluteSizes();
+                    let newSize = absoluteSizes[1] - widthDiff;
+                    let totalWidth = absoluteSizes.reduce((x, a) => x + a, 0);
+                    vpLab.shell._hsplitPanel.layout.setRelativeSizes([relativeSizes[0], newSize/totalWidth, newVpWidth/totalWidth]);
+                } else {
+                    $('#vp_wrapper').resizable({ minWidth: MENU_MIN_WIDTH + MENU_BOARD_SPACING });
+                }
                 this.menuFrame._unbindResizable();
                 
             } else {
@@ -278,7 +364,29 @@ define([
                 this.boardFrame.show();
                 newVpWidth = vpWidth + BOARD_MIN_WIDTH + MENU_BOARD_SPACING;
                 $('#vp_wrapper').width(newVpWidth);
-                $('#vp_wrapper').resizable({ minWidth: VP_MIN_WIDTH });
+                if (vpConfig.extensionType === 'lab') {
+                    // LAB: set parent width and position, min-width
+                    let target = $('#vp_wrapper').parent();
+                    let prevWidth = target[0].getBoundingClientRect().width;
+                    let prevLeft = $(target).position().left;
+                    let widthDiff = newVpWidth - vpWidth;
+                    $(target).css({
+                        width: prevWidth + widthDiff,
+                        left: prevLeft - widthDiff
+                    });
+                    $('#vp_wrapper').attr('style', `min-width: ${VP_MIN_WIDTH}px !important`);
+                    if (vpLab.shell.rightCollapsed == false) {
+                        vpLab.shell.collapseRight();
+                        vpLab.shell.expandRight();
+                    }
+                    let relativeSizes = vpLab.shell._hsplitPanel.layout.relativeSizes();
+                    let absoluteSizes = vpLab.shell._hsplitPanel.layout.absoluteSizes();
+                    let newSize = absoluteSizes[1] - widthDiff;
+                    let totalWidth = absoluteSizes.reduce((x, a) => x + a, 0);
+                    vpLab.shell._hsplitPanel.layout.setRelativeSizes([relativeSizes[0], newSize/totalWidth, newVpWidth/totalWidth]);
+                } else {
+                    $('#vp_wrapper').resizable({ minWidth: VP_MIN_WIDTH });
+                }
                 this.menuFrame._bindResizable();
             }
             // save current page info
@@ -288,7 +396,6 @@ define([
                 vp_menu_width: menuWidth
             });
 
-            // $('#vp_wrapper').trigger('resize');
             this._resizeVp(newVpWidth);
         }
 
@@ -366,13 +473,15 @@ define([
                 // loading bar enable
                 this.boardFrame.showLoadingBar();
                 // create components
-                require(loadMenuList, function() {
+                // LAB: use require
+                if (vpConfig.extensionType === 'lab') {
                     let parentBlock = null;
                     let prevBlock = null;
                     loadStateList.forEach(obj => {
                         let { blockType, menuId, menuState, menuConfig, argIdx, position, afterAction } = obj;
                         // get OptionComponent Object
-                        let OptionComponent = arguments[argIdx];
+                        // LAB: relative path needed
+                        let OptionComponent = require('./' + menuConfig.file);
                         if (OptionComponent) {
                             let taskState = menuState.taskState;
                             let blockState = menuState.blockState;
@@ -430,11 +539,79 @@ define([
                     }
                     that.boardFrame.hideLoadingBar();
                     that.boardFrame.reloadBlockList();
-                }, function (err) {
-                    vpLog.display(VP_LOG_TYPE.ERROR, 'Error on creating popup (' + err.message + ')');
-                    that.boardFrame.hideLoadingBar();
-                });
+                } else {
+                    window.require(loadMenuList, function() {
+                        let parentBlock = null;
+                        let prevBlock = null;
+                        loadStateList.forEach(obj => {
+                            let { blockType, menuId, menuState, menuConfig, argIdx, position, afterAction } = obj;
+                            // get OptionComponent Object
+                            let OptionComponent = arguments[argIdx];
+                            if (OptionComponent) {
+                                let taskState = menuState.taskState;
+                                let blockState = menuState.blockState;
+                                let tmpState = menuState.tmpState;
+                                let state = {
+                                    ...taskState,
+                                    config: menuConfig
+                                };
+                                // create popup instance
+                                let popup = new OptionComponent(state);
+                                let newBlock = null;
+                                if (blockType === 'block') {
+                                    // add to block list
+                                    newBlock = that.addBlock(popup, position, blockState);
+                                    if (parentBlock == null) {
+                                        parentBlock = newBlock; // set parent block of created block
+                                    } else {
+                                        if (!(blockState && blockState.depth != undefined) && prevBlock != null && !newBlock.isGroup) {
+                                            let newDepth = prevBlock.getChildDepth();
+                                            if (tmpState && tmpState.relativeDepth) {
+                                                newDepth = parentBlock.getChildDepth() + tmpState.relativeDepth;
+                                            }
+                                            newBlock.setDepth(newDepth);
+                                        }
+                                    }
+                                    vpLog.display(VP_LOG_TYPE.DEVELOP, 'new block ' + position + ' with depth ' + newBlock.depth);
+                                    prevBlock = newBlock;
+                                } else {
+                                    // add to task list
+                                    that.addTask(popup);
+                                }
+                                // after action
+                                if (afterAction && afterAction != '') {
+                                    switch (afterAction) {
+                                        case 'run':
+                                            popup.run();
+                                            break;
+                                        case 'add':
+                                            popup.run(false);
+                                            break;
+                                        case 'open':
+                                            that.openPopup(popup);
+                                            break;
+                                    }
+                                }
+                            } else {
+                                vpLog.display(VP_LOG_TYPE.ERROR, 'Not implemented or available menu. (menu id: '+menuConfig.id+')');
+                            }
+                        });
+                        // focus created popup
+                        if (parentBlock && parentBlock.isGroup) {
+                            parentBlock.focusItem();
+                            // scroll to new block
+                            that.boardFrame.scrollToBlock(parentBlock);
+                        }
+                        that.boardFrame.hideLoadingBar();
+                        that.boardFrame.reloadBlockList();
+                    }, function (err) {
+                        vpLog.display(VP_LOG_TYPE.ERROR, 'Error on creating popup (' + err.message + ')');
+                        that.boardFrame.hideLoadingBar();
+                    });
+                }
+                
             } catch(err) {
+                vpLog.display(VP_LOG_TYPE.ERROR, 'Error on creating popup (' + err.message + ')');
                 that.boardFrame.hideLoadingBar();
             }
         }
