@@ -1,5 +1,5 @@
 define([
-    'css!vp_base/css/component/instanceEditor.css',
+    __VP_CSS_LOADER__('vp_base/css/component/instanceEditor'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_generatorV2',
