@@ -13,14 +13,16 @@
 // [CLASS] Markdown
 //============================================================================
 define([
-    'notebook/js/mathjaxutils',
-    'components/marked/lib/marked',
-    'css!vp_base/css/m_apps/markdown.css',
+    __VP_CSS_LOADER__('vp_base/css/m_apps/markdown'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
     'vp_base/js/com/component/PopupComponent',
-    'vp_base/js/com/component/FileNavigation'
-], function(mathjaxutils, marked, markdownCss, com_String, com_util, PopupComponent, FileNavigation) {
+    'vp_base/js/com/component/FileNavigation',
+    // CHROME: remove mathjaxutils - use MathJax in colab
+    'mathjaxutils',
+    // 'marked',
+// ], function(markdownCss, com_String, com_util, PopupComponent, FileNavigation, marked, mathjaxutils) {
+], function(markdownCss, com_String, com_util, PopupComponent, FileNavigation, mathjaxutils) {
 
     // markdown default text
     const VP_MARKDOWN_DEFAULT_NEW_TITLE_TEXT = 'New Title';
@@ -37,11 +39,13 @@ define([
     class Markdown extends PopupComponent {
         _init() {
             super._init();
+
             /** Write codes executed before rendering */
             this.config.executeMode = 'markdown';
             this.config.codeview = false;
             this.config.dataview = false;
             this.config.sizeLevel = 1;
+            this.config.checkModules = ['pd'];
 
             this.state = {
                 editor: '',
@@ -126,7 +130,7 @@ define([
             var page = new com_String();
             page.appendLine('<div class="vp-divide-top">');
             page.appendLine(this.templateForToolbar());
-            page.appendFormatLine('<textarea id="{0}">{1}</textarea>', 'vp_markdownEditor', this.state.editor);
+            page.appendFormatLine('<textarea id="{0}" class="vp-state">{1}</textarea>', 'vp_markdownEditor', this.state.editor);
             page.appendFormatLine('<div id="{0}"></div>', "vp_attachEncodedDataArea");
             page.appendLine('</div>');
             page.appendFormatLine('<div id="{0}" class="vp-divide-bot">{1}</div>', 'vp_markdownPreview', this.state.preview);
@@ -148,10 +152,6 @@ define([
             </div>`;
         }
 
-        templateForDataView() {
-            return `<textarea id="vp_markdownPreview"></textarea>`;
-        }
-
         render() {
             super.render();
 
@@ -200,28 +200,46 @@ define([
             text = text_and_math[0];
             math = text_and_math[1];
 
-            var renderer = new marked.Renderer();
+            // CHROME: TODO: 4: marked is not loaded, before fix it comment it
+            if (vpConfig.extensionType === 'notebook') {
+                var marked = require('components/marked/lib/marked');
+                var renderer = new marked.Renderer();
 
-            // get block
-            let that = this;
-            let block = this.getTaskType() == 'block'? this.taskItem: null;
-            // render preview
-            marked(text, { renderer: renderer }, function (err, html) {
+                // get block
+                let block = this.getTaskType() == 'block'? this.taskItem: null;
+
+                let that = this;
+                // render preview
+                marked(text, { renderer: renderer }, function (err, html) {
+                    html = mathjaxutils.replace_math(html, math);
+                    let preview = `<div>${html}</div>`;
+                    if (html == '') {
+                        preview = '';
+                    }
+                    that.state.preview = preview;
+                    $(that.wrapSelector("#vp_markdownPreview")).html(preview);
+
+                    MathJax.Hub.Queue(["Typeset", MathJax.Hub, "vp_markdownPreview"]);
+                });
+            } else if (vpConfig.extensionType === 'lab') {
+                var marked = require('marked');
+
+                // get block
+                let block = this.getTaskType() == 'block'? this.taskItem: null;
+
+                let that = this;
+                // render preview
+                let html = marked.parse(text);
                 html = mathjaxutils.replace_math(html, math);
-                let preview = `<div>${html}</div>`;
+                let preview = `<iframe id="vp_markdownIFrame" style="width:100%;height:270px;border:0px;"></iframe>`;
                 if (html == '') {
                     preview = '';
                 }
                 that.state.preview = preview;
-                document.getElementById("vp_markdownPreview").innerHTML = preview;
-
-                MathJax.Hub.Queue(["Typeset", MathJax.Hub, "vp_markdownPreview"]);
-
-                // re render block
-                if (block) {
-                    block.render();
-                }
-            });
+                $(that.wrapSelector("#vp_markdownPreview")).html(preview);
+                $(that.wrapSelector('#vp_markdownIFrame')).contents().find('body').html(html);
+            }
+            
         }
 
         getPreview() {
@@ -306,6 +324,7 @@ define([
             // repace selection
             cm.replaceSelection(adjustText);
             // TODO: set block code
+            cm.focus();
         }
     
         /**
